# Generated by roxygen2: do not edit by hand

S3method(component_information,big_pls_cox)
S3method(component_information,big_pls_cox_gd)
S3method(coxDKgplsDR,default)
S3method(coxDKgplsDR,formula)
S3method(coxDKsgplsDR,default)
S3method(coxDKsgplsDR,formula)
S3method(coxDKspls_sgplsDR,default)
S3method(coxDKspls_sgplsDR,formula)
S3method(coxgpls,default)
S3method(coxgpls,formula)
S3method(coxgplsDR,default)
S3method(coxgplsDR,formula)
S3method(coxsgpls,default)
S3method(coxsgpls,formula)
S3method(coxsgplsDR,default)
S3method(coxsgplsDR,formula)
S3method(coxspls_sgpls,default)
S3method(coxspls_sgpls,formula)
S3method(coxspls_sgplsDR,default)
S3method(coxspls_sgplsDR,formula)
S3method(plot,big_pls_cox)
S3method(plot,big_pls_cox_gd)
S3method(predict,big_pls_cox)
S3method(predict,big_pls_cox_fast)
S3method(predict,big_pls_cox_gd)
S3method(predict,coxDKgplsDR)
S3method(predict,coxDKsgplsDR)
S3method(predict,coxDKspls_sgplsDR)
S3method(predict,coxgpls)
S3method(predict,coxgplsDR)
S3method(predict,coxsgpls)
S3method(predict,coxsgplsDR)
S3method(predict,coxspls_sgpls)
S3method(print,big_pls_cox)
S3method(print,big_pls_cox_gd)
S3method(print,summary.big_pls_cox_fast)
S3method(stats::predict,gPLS)
S3method(stats::predict,pls.cox)
S3method(stats::predict,sPLS)
S3method(stats::predict,sgPLS)
S3method(summary,big_pls_cox)
S3method(summary,big_pls_cox_fast)
S3method(summary,big_pls_cox_gd)
export(benchmark_deviance_residuals)
export(bigSurvSGD.na.omit)
export(big_pls_cox)
export(big_pls_cox_fast)
export(big_pls_cox_gd)
export(big_pls_cox_transform)
export(bigscale)
export(component_information)
export(computeDR)
export(coxDKgplsDR)
export(coxDKsgplsDR)
export(coxDKspls_sgplsDR)
export(cox_deviance_details)
export(cox_deviance_residuals)
export(cox_deviance_residuals_big)
export(cox_partial_deviance_big)
export(coxgpls)
export(coxgplsDR)
export(coxsgpls)
export(coxsgplsDR)
export(coxspls_sgpls)
export(coxspls_sgplsDR)
export(cv.big_pls_cox)
export(cv.big_pls_cox_gd)
export(cv.coxDKgplsDR)
export(cv.coxDKsgplsDR)
export(cv.coxDKspls_sgplsDR)
export(cv.coxgpls)
export(cv.coxgplsDR)
export(cv.coxsgpls)
export(cv.coxsgplsDR)
export(cv.coxspls_sgpls)
export(cv.coxspls_sgplsDR)
export(dataCox)
export(gd_diagnostics)
export(partialbigSurvSGDv0)
export(select_ncomp)
exportMethods("%*%")
exportMethods(Arith)
import(bigSurvSGD)
import(bigalgebra)
import(bigmemory)
importFrom(Rcpp,evalCpp)
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(grDevices,dev.new)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,matplot)
importFrom(graphics,segments)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,coefficients)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,extractAIC)
importFrom(stats,is.empty.model)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,model.weights)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,pt)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,rexp)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(survival,coxph)
importFrom(survival,coxph.control)
importFrom(utils,read.csv)
useDynLib(bigPLScox, .registration = TRUE)
